#
# spec file for package perl-FileHandle-Unget
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-FileHandle-Unget
Version:        0.1634
Release:        1.23
%define cpan_name FileHandle-Unget
Summary:        FileHandle which supports multi-byte unget
License:        GPL-2.0-or-later
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/FileHandle-Unget/
Source0:        https://cpan.metacpan.org/authors/id/D/DC/DCOPPIT/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(File::Slurper)
BuildRequires:  perl(Test::Compile)
BuildRequires:  perl(UNIVERSAL::require)
%{perl_requires}

%description
FileHandle::Unget operates exactly the same as FileHandle, except that it
provides a version of ungetc that allows you to unget more than one
character. It also provides ungets to unget a string.

This module is useful if the filehandle refers to a stream for which you
can't just 'seek()' backwards. Some operating systems support multi-byte
'ungetc()', but this is not guaranteed. Use this module if you want a
portable solution. In addition, on some operating systems, eof() will not
be reset if you ungetc after having read to the end of the file.

NOTE: Using 'sysread()' with 'ungetc()' and other buffering functions is
still a bad idea.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644
# MANUAL BEGIN
sed -i -e 's/use inc::Module::Install;/use lib q[.];\nuse inc::Module::Install;/' Makefile.PL
# MANUAL END

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc CHANGES README TODO
%license LICENSE

%changelog
* Tue Jul 17 2018 coolo@suse.com
- updated to 0.1634
  see /usr/share/doc/packages/perl-FileHandle-Unget/CHANGES
  Version 0.1634:
  - Fix Makefile.PL warning
  - Fix deleting of inc during release process
  - Better fix for AutomatedTester warning
  Version 0.1632:
  - Updating META.yml
  Version 0.1632:
  - Switch to File::Slurper
* Sun Jul  8 2018 coolo@suse.com
- updated to 0.1631
  see /usr/share/doc/packages/perl-FileHandle-Unget/CHANGES
* Fri Jul  6 2018 coolo@suse.com
- updated to 0.1629
  see /usr/share/doc/packages/perl-FileHandle-Unget/CHANGES
* Tue Oct  3 2017 coolo@suse.com
- patch the Makefile to build with perl 5.26
* Sun May  3 2015 coolo@suse.com
- updated to 0.1628
  see /usr/share/doc/packages/perl-FileHandle-Unget/CHANGES
  Version 0.1628: Sat May 2 2015
  - Prevent CPAN from indexing private-lib
  Version 0.1627: Mon Apr 20 2015
  - Clarify licensing terms
  - Move verbose testing to a private module, and implement it in a way that
    doesn't require editing the Makefile after it is generated.
  - Require File::Slurp instead of including it, to avoid potential problems
    like this:
    http://www.cpantesters.org/cpan/report/86a0145a-e52b-11e4-a1d1-8536eb4f9f07
  - Fix tests so that they don't prematurely delete the temp file
    See for example:
    http://www.cpantesters.org/cpan/report/3adcb600-6bf9-1014-8336-f8616735162a
  - Fix tests on Windows.
    http://www.cpantesters.org/cpan/report/482c4765-af8d-1014-8ca5-91062b825c07
  Version 0.1626: Sun Apr 12 2015
  - Enable verbose testing for CPAN-testers
  - Consolidate issue tracking at rt.cpan.org
  Version 0.1625: Sat Apr 4 2015
  - Modify the memory leak test to check for <= 0 bytes. I'm not sure how this
    scenario happens, but test failures like this indicate that it can:
    http://www.cpantesters.org/cpan/report/bdd0e36c-d0dd-11e4-954f-5702e0bfc7aa
  - Attempt to fix loss of lines when $/ is undef. Thanks to Nigel Horne for the
    automated testing that found the failure.
    http://www.cpantesters.org/cpan/report/60452d60-d3cc-11e4-b60b-c2157e3e1735
  Version 0.1624: Sun Mar 22 2015
  - Moved code to github
  - Added POD test
  - Improve testability of binmode_bug.t, stdin_tell_bug.t
  - Implement a potential fix for test failures where FileHandle::getline()
  seems to be reading a single line even though $/ is undef. Unfortunately I
  can't reproduce this failure, so I'll submit and check the CPAN Testers
  reports.
  - Use "local $/" instead of reassigning global $/. Perhaps this is somehow
  related to the test failures above?
  - Improve documentation for input_record_separator()
* Tue Jun  7 2011 coolo@novell.com
- regenerate with cpanspec
* Tue Jun  7 2011 aj@suse.de
- Add perl_requires so that it requires the right perl version.
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Sep  7 2009 mls@suse.de
- update to 0.1623 to make it build with perl-5.10.1
* Fri Jul 25 2008 anicka@suse.cz
- update to 0.1622
  * Updated to the latest version of Module::Install
  * Removed auto-install for better compatibility with CPAN
  and others
  * Moved hosting to Google Code
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan  4 2006 anicka@suse.cz
- update to 0.1621
* Tue Jun 22 2004 rommel@suse.de
- initial checkin
